# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pytest_breakword']

package_data = \
{'': ['*']}

install_requires = \
['breakword>=0.3.1,<0.4.0', 'pytest>=6.2.4,<7.0.0']

entry_points = \
{'pytest11': ['breakword = pytest_breakword.main']}

setup_kwargs = {
    'name': 'pytest-breakword',
    'version': '0.1.2',
    'description': 'Use breakword with pytest',
    'long_description': None,
    'author': 'Olivier Breuleux',
    'author_email': 'breuleux@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



import builtins
import hashlib
import os
from functools import partial

from breakword import (
    WordGroup,
    breakpoint as _breakpoint,
    common_words as cw,
    common_words_source,
    file_source,
)


def pytest_addoption(parser, pluginmanager):
    parser.addoption(
        "--bw",
        "--breakword",
        help="Breakword to use",
        default=None,
    )


def pytest_sessionstart(session):
    bw = session.config.option.bw
    if bw is not None:
        os.environ["BREAKWORD"] = bw


def pytest_runtest_setup(item):
    loc = item.location
    hsh = hashlib.md5(str((loc[0], loc[2])).encode())
    hsh = int(hsh.hexdigest(), 16)
    grp_name = cw[hsh % len(cw)]
    grp = WordGroup(
        name=grp_name,
        sources=[
            common_words_source,
            file_source("/usr/share/dict/words", exclude=cw),
        ],
    )
    builtins.breakpoint = partial(_breakpoint, group=grp)
